@@ -85,8 +85,8 @@ class LightGBMMixer(BaseMixer):
                       'device_type': self.device_str
                       }
             if objective == 'multiclass':
-                all_classes = self.ord_encs[col_name].categories_[0]
-                params['num_class'] = all_classes.size
+                self.all_classes = self.ord_encs[col_name].categories_[0]
+                params['num_class'] = self.all_classes.size
 
             num_iterations = 100
 
@@ -134,6 +134,7 @@ class LightGBMMixer(BaseMixer):
             ypred[col_name] = {}
             if col_name in self.ord_encs:
                 ypred[col_name]['class_distribution'] = list(col_preds)
+                ypred[col_name]['class_labels'] = self.all_classes
                 col_preds = self.ord_encs[col_name].inverse_transform(np.argmax(col_preds, axis=1).reshape(-1, 1)).flatten()
             ypred[col_name]['predictions'] = list(col_preds)
 
